defmodule WykopAPI.Profile do
  @moduledoc """

  """

  @api_url WykopAPI.get_api_url <> "profile/"

  @derive [Poison.Encoder]
  defstruct [
    :about, :author_group, :avatar, :avatar_big, :avatar_lo, :avatar_med,
    :buries, :city, :comments, :diggs, :email, :entries, :entries_comments,
    :followers, :following, :gg, :groups, :is_blocked, :is_observed, :jabber,
    :links_added, :links_published, :login, :name, :public_email, :rank,
    :related_links, :sex, :signup_date, :url, :violation_url, :www
  ]

  @doc """
  Retrieves user's profile
  """
  def index(username) do
    WykopAPI.get!(@api_url <> "index/" <> username
      <> "/" <> WykopAPI.param_api)
    |> Poison.decode!(as: %WykopAPI.Profile{})
  end

  @doc """
  Retrieves Mikroblog entries of one user.
  """
  def entries(username, page \\ 1) do
    map = %{
      page: page
    }
    WykopAPI.get!(@api_url <> "entries/" <> username
      <> "/" <> WykopAPI.param_api(map))
    |> Poison.decode!(as: [%WykopAPI.Entry{}])
  end

  @doc """
  Non-official
  Username colors
  """
  def color(profile) do
    case profile.author_group do
      1 -> "#ff5917" # orange
      2 -> "#bb0000" # bordo
      3 -> "#ff0000" # red
      4 -> "#999999" # banned?
      5 -> "#fff"    # admin
      1001 -> "#999999" # banned
      2001 -> "#3f6fa0" # lechwalesa
      _ -> "#339933" # green
    end
  end


end
