defmodule WykopAPI.Stream do
  @moduledoc """
  Mikroblog stream
  """

  @api_url WykopAPI.get_api_url <> "stream/"

  @doc """
  Returns list of Mikroblog entries on `page`.
  Around 46 Wykop.Entry items.
  """
  def index(page \\ 1) do
    map = %{
      page: page
    }
    WykopAPI.get!(@api_url <> "index/" <> WykopAPI.param_api(map))
    |> Poison.decode!(as: [%WykopAPI.Entry{}])
  end

  @doc """
  Non-official
  Returns histogram of Mikroblog tags on first page.
  """
  def tags do
    index
    |> Enum.reduce([], fn e, acc -> WykopAPI.Entry.tags(e) ++ acc end)
    |> Enum.reduce(%{}, fn t, acc -> Dict.update(acc, t, 1, &(&1 + 1)) end)
  end

  def tags(min), do: Enum.filter(tags, fn {_k, v} -> v >= min end)

end
